| /llvm-project-15.0.7/clang/test/SemaObjC/ |
| H A D | DoubleMethod.m | 8 - (void) method; // expected-note {{previous declaration is here}} method 9 - (void) method; // expected-warning {{multiple declarations of method 'method' found and ignored}} method 13 - (void) method {;} // expected-note {{previous declaration is here}} method 14 - (void) method {;} // expected-error {{duplicate declaration of method 'method'}} method
|
| H A D | method-redecls-invalid-interface.m | 16 -(void) method; method 20 -(void) method { } method
|
| H A D | comptypes-5.m | 8 - (void) method; method 15 - (void) method; method in Addition
|
| H A D | typo-correction.m | 36 -(void)method; method 47 -(void)method { method 70 -(void)method { method
|
| /llvm-project-15.0.7/clang/test/SemaObjCXX/ |
| H A D | ivar-lookup.mm | 4 - (float*)method; method 10 - (int*)method; method 14 - (int*)method { method
|
| H A D | message.mm | 6 - (int*)method; method 10 - (int*)method { method 22 - (int*)method; method 23 + (void)method; class 35 - (int*)method { method 43 + (void)method { class 50 + (int*)method; class
|
| H A D | dllexport.mm | 25 - (void)method; method 29 - (void)method { method
|
| H A D | dllimport.mm | 25 - (void)method; method 29 - (void)method { method
|
| /llvm-project-15.0.7/clang/test/CXX/temp/temp.fct.spec/temp.arg.explicit/ |
| H A D | p3-0x.cpp | 33 struct method { struct 34 vararg_func implementation; 36 method(vararg_func implementation) : implementation(implementation) {} in method() function 39 auto getImplementation() const -> TFunctionType in getImplementation()
|
| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | method-target.cu | 10 void method() {} // dev-note {{'method' declared here}} in method() function 21 …void method(int) {} // expected-note {{candidate function not viable: call to __host__ function fr… in method() function 22 …void method(float) {} // expected-note {{candidate function not viable: call to __host__ function … in method() function 33 __device__ void method() {} // host-note {{'method' declared here}} in method() function 44 __device__ void method() {} // host-note {{'method' declared here}} in method() function 67 void method() {} // dev-note {{'method' declared here}}; in method() function
|
| /llvm-project-15.0.7/clang/test/SemaCXX/Inputs/ |
| H A D | override-system-header.h | 5 #define STDMETHOD(method) virtual void method argument 6 #define IFACEMETHOD(method) STDMETHOD(method) argument
|
| /llvm-project-15.0.7/llvm/docs/ |
| H A D | WritingAnLLVMPass.rst | 393 .. _writing-an-llvm-pass-CallGraphSCCPass: 441 .. _writing-an-llvm-pass-runOnSCC: 465 .. _writing-an-llvm-pass-FunctionPass: 515 .. _writing-an-llvm-pass-runOnFunction: 528 .. _writing-an-llvm-pass-doFinalization-mod: 542 .. _writing-an-llvm-pass-LoopPass: 578 .. _writing-an-llvm-pass-runOnLoop: 603 .. _writing-an-llvm-pass-RegionPass: 631 .. _writing-an-llvm-pass-runOnRegion: 701 .. _writing-an-llvm-pass-registration: [all …]
|
| /llvm-project-15.0.7/clang/test/Modules/ |
| H A D | method_pool_transitive.m | 12 - (int)method; method 24 - (void)method; method
|
| /llvm-project-15.0.7/clang/test/Analysis/ |
| H A D | nullability-notes.m | 27 -(void) method; method 30 -(void) method { method
|
| /llvm-project-15.0.7/clang/test/CodeGenObjC/ |
| H A D | synchronized.m | 6 - (void)method; method 13 {
|
| H A D | protocol-comdat.m | 4 - (void) method; method 14 - (void) method { } method
|
| /llvm-project-15.0.7/clang/test/CodeGenCUDA/ |
| H A D | device-vtable.cu | 56 void H::method() {} in method() function in H 59 void __device__ D::method() {} in method() function in D
|
| /llvm-project-15.0.7/mlir/tools/mlir-tblgen/ |
| H A D | OpInterfacesGen.cpp | 42 static void emitMethodNameAndArgs(const InterfaceMethod &method, in emitMethodNameAndArgs() 169 for (auto &method : interface.getMethods()) { in emitInterfaceDef() local 207 for (auto &method : interface.getMethods()) { in emitConceptDecl() local 238 for (auto &method : interface.getMethods()) { in emitModelDecl() local 257 for (auto &method : interface.getMethods()) { in emitModelDecl() local 285 for (auto &method : interface.getMethods()) { in emitModelMethodsDef() local 319 for (auto &method : interface.getMethods()) { in emitModelMethodsDef() local 346 for (auto &method : interface.getMethods()) { in emitModelMethodsDef() local 393 for (auto &method : interface.getMethods()) { in emitTraitDecl() local 472 for (auto &method : interface.getMethods()) { in emitInterfaceDecl() local [all …]
|
| /llvm-project-15.0.7/clang/test/CodeGenCXX/ |
| H A D | optnone-templates.cpp | 33 T method(T t, U u) in method() function in template_normal_base 42 __attribute__((optnone)) int method (int t, U u) in method() function in template_normal_base 70 __attribute__((optnone)) T method(T t, U u) in method() function in template_optnone_base 79 int method (int t, U u) in method() function in template_optnone_base
|
| H A D | assume_attr.cpp | 81 __attribute__((assume("S<float>::method"))) void S<float>::method() {} in method() function in S 84 void S<int>::method() {} in method() function in S
|
| /llvm-project-15.0.7/clang/test/CodeGenObjCXX/ |
| H A D | mangle-blocks.mm | 23 - (void)method; method 27 - (void)method { method
|
| /llvm-project-15.0.7/mlir/lib/Tools/lsp-server-support/ |
| H A D | Transport.h | 133 void method(llvm::StringLiteral method, ThisT *thisPtr, in method() function 146 void notification(llvm::StringLiteral method, ThisT *thisPtr, in notification() 159 OutgoingNotification<T> outgoingNotification(llvm::StringLiteral method) { in outgoingNotification()
|
| H A D | Transport.cpp | 42 StringRef method; member in __anon441a52320111::Reply 49 Reply::Reply(const llvm::json::Value &id, llvm::StringRef method, in Reply() 81 bool MessageHandler::onNotify(llvm::StringRef method, llvm::json::Value value) { in onNotify() 96 bool MessageHandler::onCall(llvm::StringRef method, llvm::json::Value params, in onCall() 163 void JSONTransport::notify(StringRef method, llvm::json::Value params) { in notify() 170 void JSONTransport::call(StringRef method, llvm::json::Value params, in call() 238 Optional<StringRef> method = object->getString("method"); in handleMessage() local
|
| /llvm-project-15.0.7/lldb/test/API/commands/expression/context-object-objc/ |
| H A D | main.m | 13 -(int)method; method 32 -(int)method { method
|
| /llvm-project-15.0.7/clang/test/FixIt/ |
| H A D | typo.m | 100 - (int)method; // expected-note{{using}} method 106 - (int)method; // expected-note{{also found}} method 110 - (int)method { method 135 - (void)method; // expected-note{{also found}} method 141 - (void)method { method
|